@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # Agent parameters
-__version__     = '1.0.12'
+__version__     = '1.0.13'
 __author__      = 'bjbuijs'
 __author__      = 'aukeschotanus'
 
@@ -244,7 +244,12 @@ def fetch_catalog( agent ):
     catalog = {}
 
      # Open the catalog stored @ disk
-    dc = shelve.open(base.get_path() + "/rocksolid-agent.cat") # Create file when doesn't exists
+    try:
+        dc = shelve.open(base.get_path() + "/rocksolid-agent.cat") # Create file when doesn't exists
+        local_dc = 'yes'
+    except Exception, e:
+        fb.add(1, 'Unable to open/store local catalog')
+        local_dc = 'no'
 
     # Prepare the data
     query_args = { 'task'        : 'fetchcatalog',
@@ -264,8 +269,7 @@ def fetch_catalog( agent ):
     try:
         xmldoc = minidom.parseString(response)
     except Exception, e:
-        #fb.add(1, 'Unable to load the catalog .. error: ' + str(e))
-        #sys.exit(1)
+        fb.add(1, 'Unable to load the catalog from cloud, using defaults .. error: ' + str(e))
         pass
 
     # Process parameters
@@ -347,12 +351,13 @@ def fetch_catalog( agent ):
         catalog['tasks']['1']['apps'].append('SRC')
         catalog['tasks']['1']['apps'].append('MOD')
 
-    # Store the catalog on disk
-    dc['param'] = catalog['param']
-    dc['tasks'] = catalog['tasks']
+    if local_dc == 'yes':
+        # Store the catalog on disk
+        dc['param'] = catalog['param']
+        dc['tasks'] = catalog['tasks']
 
-    # Close the catalog stored @ disk
-    dc.close()
+        # Close the catalog stored @ disk
+        dc.close()
 
     return catalog
 
@@ -379,8 +384,6 @@ def run_tasks( catalog, definitions, agent ):
     fb.add(1, 'Running the tasks based on instructions and parameters in the catalog, please wait....')
 
     results = {}
-
-    #print "Processing task %"
     #dumpclean(catalog['tasks'])
 
     tasks = catalog['tasks']
@@ -394,7 +397,6 @@ def run_tasks( catalog, definitions, agent ):
         for app in apps:
             try:
                 fb.add(1, 'Running app ' + bcolors.OKBLUE + app + bcolors.ENDC + ' for task ID #' + bcolors.OKBLUE + k + bcolors.ENDC)
-
                 if   app == 'HEX' or app == 'MAT' or app == 'MD5' or app == 'SRC':
                     # Initiate all the file based apps (combined in one run to open files only ones)
                     # hex, mat, md5, src
